/* xmalloc.c -- malloc with out-of-memory checking
   Copyright (C) 1990, 1991, 1992, 1993, 1994 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
   
  /* Modified by Ron Charlton 2014-05-19 to not do something stupid like return
  a one-byte block of memory if malloc() or realloc() fails, but exit with error
  instead.  */

static char RCS_ID_xmalloc_h[] = "$Id: xmalloc.c 1.5 2017-11-19 16:40:57-05 Ron Exp $";


#define VOID void

#include <malloc.h>
#include <stddef.h>
#include <sys/types.h>
#include <stdlib.h>

#include "error.h"
#include "xmalloc.h"

#ifdef __cplusplus
extern "C" {
#endif

#ifndef EXIT_FAILURE
#define EXIT_FAILURE 1
#endif

/* Exit value when the requested amount of memory is not available.
   The caller may set it to some other value.  */
int xmalloc_exit_failure = EXIT_FAILURE;

/* Allocate N bytes of memory dynamically, with error checking.  */

VOID *xmalloc(size_t n)
{
	VOID *p;

	p = malloc(n);
	if (p == 0)
		error(xmalloc_exit_failure, 0, "out of memory");
	return p;
}

/* Change the size of an allocated block of memory P to N bytes,
   with error checking.
   If P is NULL, run xmalloc.  */

VOID *xrealloc(VOID * p, size_t n)
{
	VOID *x;
	if (p == 0)
		return xmalloc(n);
	x = p;
	p = realloc(p, n);
	if (p == 0)
		error(xmalloc_exit_failure, 0, "out of memory");
	return p;
}

#ifdef __cplusplus
}
#endif

